@@ -233,7 +233,7 @@ class Extractor(object):
             return numpy.std(a)
 
     def create_dataset(self):
-        """Read the trace files and add them to the dictionnary self.dataset"""
+        """Read the trace files and add them to the dictionary self.dataset"""
         logger.info(" Filling dataset")
 
         for i_cell, cellname in enumerate(self.cells):
@@ -1100,6 +1100,10 @@ class Extractor(object):
                     self.dataset_mean[expname]['bc_ld_features'][feature][
                         str(target)] = bcld
 
+        with open(self.maindirname + "dataset_means.json", "w") as handle:
+            json.dump(
+                self.dataset_mean, handle, indent=4, cls=tools.NumpyEncoder)
+
     def get_threshold(self, amp, numspikes):
         """Get the spiking threshold of a cell by taking the smallest current
         amplitude for which it fires"""
