@@ -7,6 +7,8 @@ import calendar
 import re
 import six
 import logging
+logger = logging.getLogger(__name__)
+import quantities as pq
 
 
 class manageFiles:
@@ -129,7 +131,7 @@ class manageMetadata:
         """
         Read metadata file into a json dictionary
         """
-        logging.info("Reading metadata " + os.path.basename(metadata_file))
+        logger.info("Reading metadata " + os.path.basename(metadata_file))
 
         crr_file_dir = os.path.dirname(__file__)
         default_metadata_file = os.path.join(
@@ -228,7 +230,7 @@ class manageMetadata:
                         for file:" + crr_dict['filename'])
             else:
                 ty = str(crr_dict['stimulus_type'])
-                logging.info("extracted stimulus type")
+                logger.info("extracted stimulus type")
 
             if 'stimulus_time_unit' not in crr_dict or not \
                     crr_dict['stimulus_time_unit'] or \
@@ -237,7 +239,7 @@ class manageMetadata:
                     for file:" + crr_dict['filename'])
             else:
                 tu = crr_dict['stimulus_time_unit']
-                logging.info("extracted stimulus unit")
+                logger.info("extracted stimulus unit")
 
             if 'stimulus_start' in crr_dict \
                     and crr_dict['stimulus_start'] and \
@@ -247,16 +249,16 @@ class manageMetadata:
                     crr_dict['stimulus_end'] != 'uknown':
                 st = crr_dict['stimulus_start'][0]
                 en = crr_dict['stimulus_end'][0]
-                logging.info("extracted stimulus start and stimulus \
+                logger.info("extracted stimulus start and stimulus \
                         end")
             elif 'tamp' in crr_dict and crr_dict['tamp']:
                 st = crr_dict['tamp'][0]
                 en = crr_dict['tamp'][1]
-                logging.info("extracted stimulus start")
+                logger.info("extracted stimulus start")
             elif 'ton' in crr_dict and 'toff' in crr_dict:
                 st = crr_dict['ton']
                 en = crr_dict['toff']
-                logging.info("extracted stimulus start")
+                logger.info("extracted stimulus start")
             else:
                 raise Exception("'stimulus_start' and/or 'stimulus_end' key \
                         absent in metadata, for file:" + crr_dict['filename'])
@@ -264,11 +266,11 @@ class manageMetadata:
             if 'stimulus_unit' in crr_dict and crr_dict['stimulus_unit'] and \
                     crr_dict["stimulus_unit"] != "unknown":
                 u = str(crr_dict['stimulus_unit'])
-                logging.info("extracted stimulus unit")
+                logger.info("extracted stimulus unit")
             elif 'i_unit' in crr_dict and crr_dict['i_unit'] and \
                     crr_dict['i_unit'] != 'unknown':
                 u = str(crr_dict['i_unit'])
-                logging.info("extracted stimulus unit")
+                logger.info("extracted stimulus unit")
             else:
                 raise Exception("'stimulus_unit' key absent in metadata, \
                         for file:" + crr_dict['filename'])
@@ -283,7 +285,7 @@ class manageMetadata:
                     format(
                         crr_dict['stimulus_first_amplitude'][0],
                         '.3f'))
-                logging.info("extracted stimulus first amplitude")
+                logger.info("extracted stimulus first amplitude")
 
             if 'stimulus_increment' not in crr_dict \
                     or crr_dict["stimulus_increment"] == "unknown":
@@ -293,16 +295,16 @@ class manageMetadata:
                 inc = float(format(0, '.3f'))
             else:
                 inc = float(format(crr_dict['stimulus_increment'][0], '.3f'))
-            logging.info("extracted stimulus increment")
+            logger.info("extracted stimulus increment")
 
             if 'sampling_rate_unit' not in crr_dict or not \
                     crr_dict['sampling_rate_unit'] \
                     or crr_dict["sampling_rate_unit"] == "unknown":
                 ru = 'Hz'
-                logging.info("extracted sampling rate unit")
+                logger.info("extracted sampling rate unit")
             else:
                 ru = crr_dict['sampling_rate_unit'][0]
-                logging.info("extracted sampling rate unit")
+                logger.info("extracted sampling rate unit")
 
             if 'sampling_rate' not in crr_dict or not \
                     crr_dict['sampling_rate'] or \
@@ -311,16 +313,17 @@ class manageMetadata:
                         file:" + crr_dict['filename'])
             else:
                 r = crr_dict['sampling_rate'][0]
-                logging.info("extracted sampling rate")
+                logger.info("extracted sampling rate")
 
             if tu == 's':
                 st = st * 1e3
                 en = en * 1e3
         except Exception as e:
-            print(
+            logger.error(
                 'Error in reading keys for stimulus extraction in file: ' +
-                crr_dict['filename'])
-            print('ERROR ' + str(e))
+                crr_dict['filename']
+            )
+            logger.error('ERROR ' + str(e))
 
         all_stim_feats = {
             "ty": [],
@@ -413,31 +416,23 @@ class manageMetadata:
         """
         Fill holdcurr (i.e. holding current) field
         """
-        hca = "holding_current_amp"
-        hcs = "holding_current_start"
-        hce = "holding_current_end"
+        hca = "holding_current"
         hcu = "holding_current_unit"
-        hctu = "holding_current_time_unit"
 
         holding_current = {}
 
-        if hca and hcs and hce and hcu and hctu in crr_dict:
+        if hca and hcu in crr_dict:
 
             chca = crr_dict[hca]
-            chcs = crr_dict[hcs]
-            chce = crr_dict[hce]
             chcu = crr_dict[hcu]
-            chctu = crr_dict[hctu]
 
-            if chca and chcs and chce and chcu and chctu:
-                chca = chca[0] * conversion_factor(amp_unit, chcu)
+            if chca and chcu:
+                chca = chca[0] * manageConfig.conversion_factor(amp_unit, chcu)
                 holding_current = {
                     "holdcurr": {
-                        "value": [chca], "holdcurrstart": chcs,
-                        "holdcurrend": chce, "holdcurru": chcu,
-                        "holdcurrtu": chctu,
+                        "value": [chca], "holdcurru": amp_unit,
                         "message": "Applied holding current: " + str(chca) +
-                        " " + chcu
+                        " " + amp_unit
                     }
                 }
         return holding_current
@@ -523,7 +518,7 @@ class manageConfig():
                 crr_exc_u = 'nA'
             elif len(cells_cellname["exclude"]) == \
                     len(cells_cellname["exclude_unit"]):
-                crr_exc_u = exclude_units[idx]
+                crr_exc_u = cells_cellname["exclude_unit"][idx]
             else:
                 raise ValueError(
                     "'exclude' and 'exclude_unit' lists must " +
